@@ -6,9 +6,10 @@ logging.basicConfig(format='%(levelname)s -> %(message)s', level=logging.INFO)
 
 
 class BaseSink(object):
-    def __init__(self, service_account_json: str) -> None:
+    def __init__(self, service_account_json: str, project: str) -> None:
         self.service_account = service_account_json
-        self.writer = GCSWriter(service_account_info=self.service_account)
+        self.project = project
+        self.writer = GCSWriter(service_account_info=self.service_account, gcp_project=self.project)
 
     def write_gcs(self, df: pd.DataFrame, bucket: str, file_path: str, file_name: str, files_format: str) -> None:
 
