@@ -40,3 +40,11 @@ class PipelineTransformations(object):
             df = df.explode(col)
 
         return df
+
+    @staticmethod
+    def _get_value_from_request(request_json: dict, value: str):
+        if request_json and value in request_json:
+            return request_json[value]
+        else:
+            raise Exception(f'No {value} in HTTP call')
+
